@@ -392,6 +392,7 @@ class GeometryElliptic(BaseElementGeometry):
 
         self.plot_resolution = 60  # Number of points to plot
 
+    """
     def get_dimension(self, distance_unitless, horizontal):
         start = self.start_point
         end = self.next_start_point
@@ -409,6 +410,31 @@ class GeometryElliptic(BaseElementGeometry):
         ellipse_p_side, ellipse_n_side = ellipse_calculation(ellipse_pos, start, end, start_dim, end_dim,
                                                              minor_axis)
         return 2.0 * ellipse_p_side
+    """
+
+    def get_width(self, distance_unitless):
+        start = self.start_point
+        end = self.next_start_point
+
+        start_dim = self.start_width
+        end_dim = self.end_width
+        minor_axis = self.minor_axis_x
+
+        ellipse_pos = (end - start) * distance_unitless
+        ellipse_p_side, ellipse_n_side = ellipse_calculation(ellipse_pos, start, end, start_dim, end_dim, minor_axis)
+        return 2.0 * ellipse_p_side
+
+    def get_height(self, distance_unitless):
+        start = self.start_point
+        end = self.next_start_point
+
+        start_dim = self.start_height
+        end_dim = self.end_height
+        minor_axis = self.minor_axis_y
+
+        ellipse_pos = (end - start) * distance_unitless
+        ellipse_p_side, ellipse_n_side = ellipse_calculation(ellipse_pos, start, end, start_dim, end_dim, minor_axis)
+        return 2.0 * ellipse_p_side
 
 
 def ellipse_calculation(ellipse_pos, start, end, start_dim, end_dim, minor_axis):
