@@ -76,6 +76,13 @@ class Gap(guide_elements.GuideElement):
         gap = self.current_instrument.add_component(self.end_component_name, "Arm")
         gap.set_AT([0, 0, self.get_length_name()], RELATIVE=self.reference_component_name)
 
+    def get_source_focus(self):
+        """
+        A source does not need to focus on a Gap, so it can be skipped.
+        """
+
+        return None
+
     def get_geometry(self):
         return GeometryGap(start_point=self.start_point_parameter,
                            next_start_point=self.next_start_point_parameter,
