@@ -1,6 +1,7 @@
 import numpy as np
 from guide_bot.base_elements import guide_elements
-from guide_bot.base_elements.guide_elements import PositionAndRotation
+from guide_bot.base_elements.base_element_geometry import BaseElementGeometry
+from guide_bot.base_elements.base_element_geometry import PositionAndRotation
 
 
 class Straight(guide_elements.GuideElement):
@@ -115,71 +116,16 @@ class Straight(guide_elements.GuideElement):
         end = self.current_instrument.add_component(self.end_component_name, "Arm")
         end.set_AT([0, 0, self.get_length_name()], RELATIVE=guide)
 
-
-def plot_element_horizontal(ax, par_dict, color):
-
-    start = par_dict["start_point"]
-    end = par_dict["next_start_point"]
-    start_width = par_dict["start_width"]
-    end_width = par_dict["end_width"]
-
-    ax.plot([start, end], [0.5*start_width, 0.5*end_width], color=color)
-    ax.plot([start, end], [-0.5*start_width, -0.5*end_width], color=color)
+    def get_geometry(self):
+        return GeometryStraight(start_point=self.start_point_parameter,
+                                next_start_point=self.next_start_point_parameter,
+                                start_width=self.start_width, start_height=self.start_height,
+                                end_width=self.end_width, end_height=self.end_height)
 
 
-def plot_element_vertical(ax, par_dict, color):
+class GeometryStraight(BaseElementGeometry):
+    def __init__(self, start_point, next_start_point, start_width, start_height, end_width, end_height):
 
-    start = par_dict["start_point"]
-    end = par_dict["next_start_point"]
-    start_height = par_dict["start_height"]
-    end_height = par_dict["end_height"]
-
-    ax.plot([start, end], [0.5*start_height, 0.5*end_height], color=color)
-    ax.plot([start, end], [-0.5*start_height, -0.5*end_height], color=color)
-
-
-def guide_width(par_dict, distance_unit_less):
-    start_width = par_dict["start_width"]
-    end_width = par_dict["end_width"]
-
-    return start_width + (end_width - start_width) * distance_unit_less
-
-
-def guide_height(par_dict, distance_unit_less):
-    start_height = par_dict["start_height"]
-    end_height = par_dict["end_height"]
-
-    return start_height + (end_height - start_height)*distance_unit_less
-
-
-def guide_dimensions(par_dict, distance_unitless, horizontal):
-
-    if horizontal:
-        start_width = par_dict["start_width"]
-        end_width = par_dict["end_width"]
-
-        return start_width + (end_width - start_width) * distance_unitless
-
-    else:
-        start_height = par_dict["start_height"]
-        end_height = par_dict["end_height"]
-
-        return start_height + (end_height - start_height) * distance_unitless
-
-
-def center_line(start_pr, par_dict, distance_unit_less):
-
-    start = par_dict["start_point"]
-    end = par_dict["next_start_point"]
-
-    length = end - start
-    this_position = length*distance_unit_less
-
-    z_vector = np.array([0, 0, 1])
-
-    start_direction = start_pr.rotation
-    z_vector = start_direction.apply(z_vector)
-
-    updated_position = start_pr.position + this_position*z_vector
-
-    return PositionAndRotation(updated_position, start_pr.rotation)
\ No newline at end of file
+        super().__init__(start_point=start_point, next_start_point=next_start_point,
+                         start_width=start_width, start_height=start_height,
+                         end_width=end_width, end_height=end_height)
\ No newline at end of file
