@@ -264,7 +264,7 @@ class GeometryWolter_EH(BaseElementGeometry):
         self.plot_resolution = 60  # Number of points to plot
         self.linestyle = "--"
 
-    def get_dimension(self, distance_unit_less, horizontal=True):
+    def get_dimension_wolter(self, distance_unit_less, horizontal=True):
         start = self.start_point
         end = self.next_start_point
         length = end - start
@@ -296,6 +296,12 @@ class GeometryWolter_EH(BaseElementGeometry):
 
         raise RuntimeError("Failure in get_dimension logic for Wolter.")
 
+    def get_width(self, distance_unit_less):
+        return self.get_dimension_wolter(distance_unit_less, horizontal=True)
+
+    def get_height(self, distance_unit_less):
+        return self.get_dimension_wolter(distance_unit_less, horizontal=False)
+
     def plot_extra(self, ax, start_pr, horizontal=True, color="black"):
         if start_pr is None:
             start_pr = self.create_start_pr()
