@@ -5,12 +5,16 @@ import copy
 import numpy as np
 import yaml
 import mmap
+import matplotlib.pyplot as plt
+import matplotlib.cm as cm
 
 import ipywidgets as widgets
 from IPython.display import display
 
 from mcstasscript.interface import instr, functions, plotter
 
+from guide_bot.logging.log_plotter import LogPlotter
+
 
 class SingleRun:
     def __init__(self, path, ref_path=None):
@@ -44,7 +48,7 @@ class SingleRun:
             ref_monitor_sizes = self.load_monitor_sizes(self.ref_path + ".yaml")
         else:
             self.ref_metadata_list = None
-            ref_monitor_size = {}
+            ref_monitor_sizes = {}
 
         self.monitor_info = {}
         for metadata in self.main_metadata_list:
@@ -52,7 +56,9 @@ class SingleRun:
                                                           "has_ref": False, "ref_data": None}
             self.monitor_info[metadata.component_name]["metadata"] = metadata
             if metadata.component_name in monitor_sizes:
-                self.monitor_info[metadata.component_name]["size"] = monitor_sizes[metadata.component_name]
+                #self.monitor_info[metadata.component_name]["size"] = monitor_sizes[metadata.component_name]
+                size = monitor_sizes[metadata.component_name]
+                self.monitor_info[metadata.component_name]["size"] = self.get_monitor_size_value(size, metadata)
             else:
                 self.monitor_info[metadata.component_name]["size"] = None
 
@@ -64,8 +70,10 @@ class SingleRun:
                     self.monitor_info[metadata.component_name]["ref_data"] = None
                     self.monitor_info[metadata.component_name]["normalized_data"] = None
 
-                if metadata.component_name in monitor_sizes:
-                    self.monitor_info[metadata.component_name]["ref_size"] = ref_monitor_sizes[metadata.component_name]
+                if metadata.component_name in ref_monitor_sizes:
+                    size = ref_monitor_sizes[metadata.component_name]
+                    #self.monitor_info[metadata.component_name]["ref_size"] = ref_monitor_sizes[metadata.component_name]
+                    self.monitor_info[metadata.component_name]["ref_size"] = self.get_monitor_size_value(size, metadata)
                 else:
                     self.monitor_info[metadata.component_name]["ref_size"] = None
 
@@ -89,6 +97,21 @@ class SingleRun:
             elif len(dimension) == 2:
                 self.monitor_2D_list.append(monitor)
 
+    def get_monitor_size_value(self, size_data, metadata):
+        """
+        Gets value from monitor database and metadata,
+
+        The size_data can be floats, in which case they are returned,
+        they can also be names that need to looked up in metadata. It
+        is also possible it is an expression with names from the
+        metadata that then needs to be evaluated first.
+
+        Returns list of horizontal / vertical length in [m]
+        """
+
+        return [read_field(size_data[0], metadata),
+                read_field(size_data[1], metadata)]
+
     def load_monitor_sizes(self, path):
         if not os.path.isfile(path):
             return {}
@@ -164,7 +187,7 @@ class SingleRun:
                 ref_area = mon_info["ref_size"][0]*mon_info["ref_size"][1]
                 area_ratio = ref_area / area
 
-            normalized_data = copy.deepcopy(data)
+            normalized_data = copy.copy(data)
             normalized_data.Intensity /= ref_data.Intensity
             normalized_data.Intensity *= area_ratio
             normalized_data.Error = np.sqrt(data.Error**2 + ref_data.Error**2)
@@ -320,6 +343,13 @@ class SourceAnalysis:
     def get_run_list(self):
         return list(self.runs.keys())
 
+    def get_log_plotter(self):
+        self.find_logs()
+        return LogPlotter(self.log_file, self.guide_log_file)
+
+    def overview_plot(self):
+        self.get_log_plotter().plot_overview()
+
 
 class ScanOverview:
     def __init__(self, project_path):
@@ -332,24 +362,24 @@ class ScanOverview:
         # build up paths for expected data directories
         self.guides = self.overview["guide_names"]
 
-        self.sample_scan = self.overview["sample"]["sample_scan"]
+        self.target_scan = self.overview["target"]["target_scan"]
         self.moderator_scan = self.overview["moderator"]["moderator_scan"]
 
-        if "sample_units" in self.overview["sample"]:
-            self.sample_scan_units = self.overview["sample"]["sample_units"]
+        if "target_units" in self.overview["target"]:
+            self.target_scan_units = self.overview["target"]["target_units"]
         else:
-            self.sample_scan_units = None
+            self.target_scan_units = None
 
         if "moderator_units" in self.overview["moderator"]:
             self.moderator_scan_units = self.overview["moderator"]["moderator_units"]
         else:
             self.moderator_scan_units = None
 
-        # build up a list of scanned parameters (sample first)
-        self.scan_list_sample = list(self.sample_scan.keys())
-        scan_list_sample_lengths = []
-        for par_name in self.scan_list_sample:
-            scan_list_sample_lengths.append(len(self.sample_scan[par_name]))
+        # build up a list of scanned parameters (target first)
+        self.scan_list_target = list(self.target_scan.keys())
+        scan_list_target_lengths = []
+        for par_name in self.scan_list_target:
+            scan_list_target_lengths.append(len(self.target_scan[par_name]))
 
         # moderator
         self.scan_list_moderator = list(self.moderator_scan.keys())
@@ -358,11 +388,11 @@ class ScanOverview:
             scan_list_moderator_lengths.append(len(self.moderator_scan[par_name]))
 
         # Collected scan
-        self.total_scan_pars = len(self.scan_list_sample) + len(self.scan_list_moderator)
+        self.total_scan_pars = len(self.scan_list_target) + len(self.scan_list_moderator)
 
-        self.scan_list_cut = len(self.scan_list_sample)
-        self.scan_list = self.scan_list_sample + self.scan_list_moderator
-        self.scan_lengths = scan_list_sample_lengths + scan_list_moderator_lengths
+        self.scan_list_cut = len(self.scan_list_target)
+        self.scan_list = self.scan_list_target + self.scan_list_moderator
+        self.scan_lengths = scan_list_target_lengths + scan_list_moderator_lengths
 
         # Get list of moderators for which analysis was performed
         self.moderator_list = []
@@ -371,6 +401,7 @@ class ScanOverview:
 
         self.data = {} # Will contain loaded data
         self.log = {} # Will contain path to main log file
+        self.log_plotter = {} # Will contain log_plotter objects (when loaded)
 
         self.succesful_indices = {}
 
@@ -383,31 +414,31 @@ class ScanOverview:
     def get_shape(self):
         return self.scan_lengths
 
-    def get_scanned_sample_parameters(self):
-        return self.scan_list_sample
+    def get_scanned_target_parameters(self):
+        return self.scan_list_target
 
-    def get_par_index_sample(self, parameter):
-        if parameter not in self.scan_list_sample:
-            raise KeyError("Parameter name not found in sample scan list")
+    def get_par_index_target(self, parameter):
+        if parameter not in self.scan_list_target:
+            raise KeyError("Parameter name not found in target scan list")
 
-        return self.scan_list_sample.index(parameter)
+        return self.scan_list_target.index(parameter)
 
-    def get_scanned_sample_parameter_values(self, par):
-        return self.sample_scan[par]
+    def get_scanned_target_parameter_values(self, par):
+        return self.target_scan[par]
 
-    def get_scanned_sample_unit(self, par):
-        if self.sample_scan_units is not None:
-            if par in self.sample_scan_units:
-                return self.sample_scan_units[par]
+    def get_scanned_target_unit(self, par):
+        if self.target_scan_units is not None:
+            if par in self.target_scan_units:
+                return self.target_scan_units[par]
 
         return None
 
-    def get_global_index_from_sample_index(self, index):
+    def get_global_index_from_target_index(self, index):
         return index
 
-    def get_global_index_from_sample_parameter(self, parameter):
-        index = self.get_scanned_sample_parameters().index(parameter)
-        return self.get_global_index_from_sample_index(index)
+    def get_global_index_from_target_parameter(self, parameter):
+        index = self.get_scanned_target_parameters().index(parameter)
+        return self.get_global_index_from_target_index(index)
 
     def get_scanned_moderator_parameters(self):
         return self.scan_list_moderator
@@ -443,15 +474,15 @@ class ScanOverview:
 
     def get_type_from_index(self, index):
         if index < self.scan_list_cut:
-            return "sample"
+            return "target"
         else:
             return "moderator"
 
     def get_scan_values(self, index):
         parameter_name = self.get_scanned_parameters()[index]
         scan_type = self.get_type_from_index(index)
-        if scan_type == "sample":
-            return self.sample_scan[parameter_name]
+        if scan_type == "target":
+            return self.target_scan[parameter_name]
         elif scan_type == "moderator":
             return self.moderator_scan[parameter_name]
         else:
@@ -464,8 +495,8 @@ class ScanOverview:
             type = self.get_type_from_index(index)
             if type == "moderator":
                 unit = self.get_scanned_moderator_unit(parameter)
-            elif type == "sample":
-                unit = self.get_scanned_sample_unit(parameter)
+            elif type == "target":
+                unit = self.get_scanned_target_unit(parameter)
 
             print(type.ljust(12) + parameter.ljust(10) + str(values) + " [" + unit + "]")
 
@@ -486,12 +517,12 @@ class ScanOverview:
             if indices[index] < 0:
                 raise IndexError("Index less than 0 for nr: " + str(index))
 
-        sample_scan = indices[0:self.scan_list_cut]
+        target_scan = indices[0:self.scan_list_cut]
         mod_scan = indices[self.scan_list_cut:]
 
-        sample_dict = {}
-        for index in range(len(sample_scan)):
-            sample_dict[self.scan_list_sample[index]] = sample_scan[index]
+        target_dict = {}
+        for index in range(len(target_scan)):
+            target_dict[self.scan_list_target[index]] = target_scan[index]
 
         mod_dict = {}
         for index in range(len(mod_scan)):
@@ -500,8 +531,8 @@ class ScanOverview:
         # todo: update this inefficient search
         for scan_state in self.overview["scan_states"]:
 
-            sample_state = scan_state["sample_scan"]
-            if sample_dict != sample_state:
+            target_state = scan_state["target_scan"]
+            if target_dict != target_state:
                 continue
 
             mod_state = scan_state["moderator_scan"]
@@ -595,6 +626,7 @@ class ScanOverview:
 
         self.data[guide] = {}
         self.log[guide] = {}
+        self.log_plotter[guide] = {}
 
         scan = np.ndindex(*self.get_shape())
         while True:
@@ -605,6 +637,8 @@ class ScanOverview:
 
             self.log[guide][state] = {}
             self.log[guide][state]["main"] = {}
+            self.log_plotter[guide][state] = {}
+            self.log_plotter[guide][state]["main"] = None
 
             expected_guide_log_path = self.get_base_data_location(guide, state) + ".guide_log"
             if os.path.isfile(expected_guide_log_path):
@@ -645,6 +679,8 @@ class ScanOverview:
                     self.log[guide][state][mod]["log"] = None
                     self.log[guide][state][mod]["guide_log"] = None
 
+                self.log_plotter[guide][state][mod] = None
+
             if any_success:
                 if guide not in self.succesful_indices:
                     self.succesful_indices[guide] = []
@@ -654,5 +690,100 @@ class ScanOverview:
         for guide in self.get_guide_names():
             self.load_guide_run_information(guide)
 
+    def get_log_plotter(self, guide, state, mod):
+        if self.log_plotter[guide][state][mod] is not None:
+            return self.log_plotter[guide][state][mod]
+
+        log_file = self.log[guide][state][mod]["log"]
+        guide_log_file = self.log[guide][state][mod]["guide_log"]
+        if log_file is None:
+            print("log file not found for this combination.")
+            return None
+
+        if guide_log_file is None:
+            print("guide log file not found for this combination.")
+            return None
+
+        self.log_plotter[guide][state][mod] = LogPlotter(log_file, guide_log_file)
+        return self.log_plotter[guide][state][mod]
+
+    def plot_fom_guide_overview_ax(self, ax, guide, mod="main", cs_start=0, cs_end=1, **kwargs):
+        log_plotters = []
+        scan = np.ndindex(*self.get_shape())
+        while True:
+            try:
+                state = next(scan)
+            except StopIteration:
+                break
+
+            log_plotter = self.get_log_plotter(guide, state, mod)
+            if log_plotter is not None:
+                log_plotters.append(log_plotter)
+
+        colors = cm.rainbow(np.linspace(cs_start, cs_end, len(log_plotters)))
+        for log_plotter, color in zip(log_plotters, colors):
+            log_plotter.plot_1D_fom_ax(ax, color=color, **kwargs)
+
+    """
+    def plot_fom_guide_overview(self, guide, mod="main", figsize=(12, 8), **kwargs):
+        fig, ax = plt.subplots(figsize=figsize)
+        self.plot_fom_guide_overview_ax(ax=ax, guide=guide, mod=mod, **kwargs)
+
+        add_side_legend(ax)
+    """
+
+    def plot_fom_overview(self, guide=None, mod="main", figsize=(12,8), **kwargs):
+        if guide is None:
+            guides_to_plot = self.get_guide_names()
+        else:
+            guides_to_plot = [guide]
+
+        fig, ax = plt.subplots(figsize=figsize)
+        n_guides = len(guides_to_plot)
+        cs_start = [x / n_guides for x in range(n_guides)]
+        cs_end = [(x + 1) / n_guides for x in range(n_guides)]
+        for guide, cs_s, cs_e in zip(guides_to_plot, cs_start, cs_end):
+            self.plot_fom_guide_overview_ax(ax=ax, guide=guide, mod=mod, cs_start=cs_s, cs_end=cs_e, **kwargs)
+
+        add_side_legend(ax)
 
 
+def add_side_legend(ax):
+    # Shrink current axis by 20%
+    box = ax.get_position()
+    ax.set_position([box.x0, box.y0, box.width * 0.7, box.height])
+
+    # Put a legend to the right of the current axis
+    ax.legend(loc='center left', bbox_to_anchor=(1, 0.5), fontsize=7)
+    plt.show()
+
+
+def read_field(field, metadata):
+
+    value = None
+    try:
+        # If a float or int is given directly, just read that
+        value = float(field)
+    except ValueError:
+        # If a parameter name is given directly, look that up
+        if field in metadata.parameters:
+            value = metadata.parameters[field]
+
+    # Last attempt to read using python eval in case a simple expression is used
+    # This will catch for example "2.0*target_width"
+    if value is None:
+        try:
+            # Try to evaluate field with scope of all instrument parameters
+            value = eval(field, metadata.parameters)
+        except:
+            value = None
+
+    try:
+        value = float(value)
+    except ValueError:
+        # Do not want to return a string
+        value = None
+    except TypeError:
+        value = None
+
+    return value
