@@ -287,6 +287,28 @@ class Guide:
         last_element.set_end_dimensions(target_dimensions[0], target_dimensions[1])
         last_element.add_to_instr()
 
+    def get_source_focus(self, target):
+        """
+        Method to provide focusing info dict for this guide
+
+        Focusing info dict contains information used by a source to focus on
+        this guide. It may skip some modules if they are not suitable for
+        focusing, for example a Gap. Some modules have special focusing
+        requirements. The first module that does not return None is used.
+        """
+
+        for element in self.guide_elements:
+            focus_info = element.get_source_focus()
+            if focus_info is not None:
+                return focus_info
+
+        # If no module in the guide had focus info, focus on the sample
+        focus_info["dist"] = target["target_guide_distance"]
+        focus_info["width"] = target["width"]
+        focus_info["height"] = target["height"]
+
+        return focus_info
+
     def write_log_file(self, filename):
         # Start file
         with open(filename, "w") as file:
