@@ -463,7 +463,8 @@ def propagate_fixed_lengths_to_start_points(elements, total_length):
                 previous_element.start_point = ipars.FixedInstrumentParameter(par_name, previous_fixed_start)
             else:
                 # If a start point was already assigned, check it is consistent with calculation
-                if previous_element.start_point.get_value() != previous_fixed_start:
-                    raise RunTimeError("Error in input string, fixed start and fixed length disagrees")
+                if abs(previous_element.start_point.get_value() - previous_fixed_start) > 0.00001:
+                    print(previous_element.start_point.get_value(), previous_fixed_start)
+                    raise RuntimeError("Error in input string, fixed start and fixed length disagrees")
 
 
