@@ -165,12 +165,17 @@ class Target(BaseTarget):
             Instrument object to which the monitor is added
         """
 
+        mcstas_version = instrument.mccode_version
+
         mon = instrument.add_component("psd_lin_horizontal", "PSDlin_monitor")
-        mon.nx = 300
         mon.filename = '"psd_lin_horizontal.dat"'
         mon.xwidth = "2.0*target_width"
         mon.yheight = "target_height"
         mon.restore_neutron = 1
+        if mcstas_version == 2:
+            mon.nx = 300
+        else:
+            mon.nbins = 300
         mon.set_AT([0, 0, 0], RELATIVE=self.target_gap.end_component_name)
 
         info = self.plot_info.new(mon, title="Horizontal position")
@@ -178,7 +183,10 @@ class Target(BaseTarget):
         info.set_plot_options(x_axis_multiplier=100)
 
         mon = instrument.add_component("psd_lin_vertical", "PSDlin_monitor")
-        mon.nx = 300
+        if mcstas_version == 2:
+            mon.nx = 300
+        else:
+            mon.nbins = 300
         mon.filename = '"psd_lin_vertical.dat"'
         mon.xwidth = "2.0*target_height"
         mon.yheight = "target_width"
@@ -190,10 +198,17 @@ class Target(BaseTarget):
         info.set_xlabel("Vertical position [cm]")
         info.set_plot_options(x_axis_multiplier=100)
 
-        mon = instrument.add_component("divergence_horizontal", "Hdiv_monitor")
-        mon.nh = 200
+        if mcstas_version == 2:
+            mon = instrument.add_component("divergence_horizontal", "Hdiv_monitor")
+            mon.nh = 200
+            mon.h_maxdiv = 2 * self["div_horizontal"]
+        else:
+            mon = instrument.add_component("divergence_horizontal", "Div1D_monitor")
+            mon.ndiv = 200
+            mon.maxdiv = 2 * self["div_horizontal"]
+            mon.vertical = 0
+
         mon.filename = '"divergence_horizontal.dat"'
-        mon.h_maxdiv = 2 * self["div_horizontal"]
         mon.xwidth = "target_width"
         mon.yheight = "target_height"
         mon.restore_neutron = 1
@@ -203,15 +218,24 @@ class Target(BaseTarget):
         info = self.plot_info.new(mon, title="Horizontal divergence")
         info.set_xlabel("Horizontal divergence [deg]")
 
-        mon = instrument.add_component("divergence_vertical", "Hdiv_monitor")
-        mon.nh = 200
+
+        if mcstas_version == 2:
+            mon = instrument.add_component("divergence_vertical", "Hdiv_monitor")
+            mon.nh = 200
+            mon.h_maxdiv = 2 * self["div_vertical"]
+            mon.set_ROTATED([0, 0, 90], RELATIVE="psd_lin_horizontal")
+        else:
+            mon = instrument.add_component("divergence_vertical", "Div1D_monitor")
+            mon.ndiv = 200
+            mon.maxdiv = 2 * self["div_vertical"]
+            mon.vertical = 1
+            mon.set_ROTATED([0, 0, 0], RELATIVE="psd_lin_horizontal")
+
         mon.filename = '"divergence_vertical.dat"'
-        mon.h_maxdiv = 2 * self["div_vertical"]
         mon.xwidth = "target_height"
         mon.yheight = "target_width"
         mon.restore_neutron = 1
         mon.set_AT([0, 0, 1E-6], RELATIVE="PREVIOUS")
-        mon.set_ROTATED([0, 0, 90], RELATIVE="psd_lin_horizontal")
 
         info = self.plot_info.new(mon, title="Vertical divergence")
         info.set_xlabel("Vertical divergence [deg]")
@@ -261,10 +285,16 @@ class Target(BaseTarget):
         info.set_xlabel("Wavelength [AA]")
 
         mon = instrument.add_component("Acceptance_horizontal", "DivPos_monitor")
-        mon.nh = 200
+        if mcstas_version == 2:
+            mon.nh = 200
+            mon.maxdiv_h = 2 * self["div_horizontal"]
+        else:
+            mon.nb = 200
+            mon.maxdiv = 2 * self["div_horizontal"]
+            mon.vertical = 0
+
         mon.ndiv = 200
         mon.filename = '"Acceptance_horizontal.dat"'
-        mon.maxdiv_h = 2 * self["div_horizontal"]
         mon.xwidth = "2.0*target_width"
         mon.yheight = "target_height"
         mon.restore_neutron = 1
@@ -277,15 +307,22 @@ class Target(BaseTarget):
         info.set_plot_options(x_axis_multiplier=100)
 
         mon = instrument.add_component("Acceptance_vertical", "DivPos_monitor")
-        mon.nh = 200
+        if mcstas_version == 2:
+            mon.nh = 200
+            mon.maxdiv_h = 2 * self["div_vertical"]
+            mon.set_ROTATED([0, 0, 90], RELATIVE="psd_lin_horizontal")
+        else:
+            mon.nb = 200
+            mon.maxdiv = 2 * self["div_vertical"]
+            mon.vertical = 1
+            mon.set_ROTATED([0, 0, 0], RELATIVE="psd_lin_horizontal")
         mon.ndiv = 200
         mon.filename = '"Acceptance_vertical.dat"'
-        mon.maxdiv_h = 2 * self["div_vertical"]
         mon.xwidth = "2.0*target_height"
         mon.yheight = "target_width"
         mon.restore_neutron = 1
         mon.set_AT([0, 0, 1E-6], RELATIVE="PREVIOUS")
-        mon.set_ROTATED([0, 0, 90], RELATIVE="psd_lin_horizontal")
+
 
         info = self.plot_info.new(mon, title="Acceptance vertical")
         info.set_xlabel("Vertical position [cm]")
@@ -347,6 +384,8 @@ class Target(BaseTarget):
 
         """
 
+        mcstas_version = instrument.mccode_version
+
         instrument.add_declare_var("double", "div_h", comment="Horizontal divergence at target position")
         instrument.add_declare_var("double", "div_h_limit", value=self["div_horizontal"])
         instrument.add_declare_var("int", "inside_h_div",
@@ -371,7 +410,10 @@ class Target(BaseTarget):
         arm.append_EXTEND("else inside_div=0;")
 
         mon = instrument.add_component("psd_lin_horizontal_brill", "PSDlin_monitor")
-        mon.nx = 300
+        if mcstas_version == 2:
+            mon.nx = 300
+        else:
+            mon.nbins = 300
         mon.filename = '"psd_lin_horizontal_brill.dat"'
         mon.xwidth = "2.0*target_width"
         mon.yheight = "target_height"
@@ -385,7 +427,10 @@ class Target(BaseTarget):
         info.set_plot_options(x_axis_multiplier=100)
 
         mon = instrument.add_component("psd_lin_vertical_brill", "PSDlin_monitor")
-        mon.nx = 300
+        if mcstas_version == 2:
+            mon.nx = 300
+        else:
+            mon.nbins = 300
         mon.filename = '"psd_lin_vertical_brill.dat"'
         mon.xwidth = "2.0*target_height"
         mon.yheight = "target_width"
@@ -399,10 +444,17 @@ class Target(BaseTarget):
         info.set_ylabel("Brilliance transfer [1]")
         info.set_plot_options(x_axis_multiplier=100)
 
-        mon = instrument.add_component("divergence_horizontal_brill", "Hdiv_monitor")
-        mon.nh = 200
+
+        if mcstas_version == 2:
+            mon = instrument.add_component("divergence_horizontal_brill", "Hdiv_monitor")
+            mon.nh = 200
+            mon.h_maxdiv = 2 * self["div_horizontal"]
+        else:
+            mon = instrument.add_component("divergence_horizontal_brill", "Div1D_monitor")
+            mon.ndiv = 200
+            mon.maxdiv = 2 * self["div_horizontal"]
+
         mon.filename = '"divergence_horizontal_brill.dat"'
-        mon.h_maxdiv = 2 * self["div_horizontal"]
         mon.xwidth = "target_width"
         mon.yheight = "target_height"
         mon.restore_neutron = 1
@@ -414,15 +466,23 @@ class Target(BaseTarget):
         info.set_xlabel("Horizontal divergence [deg]")
         info.set_ylabel("Brilliance transfer [1]")
 
-        mon = instrument.add_component("divergence_vertical_brill", "Hdiv_monitor")
-        mon.nh = 200
+        if mcstas_version == 2:
+            mon = instrument.add_component("divergence_vertical_brill", "Hdiv_monitor")
+            mon.nh = 200
+            mon.h_maxdiv = 2 * self["div_vertical"]
+            mon.set_ROTATED([0, 0, 90], RELATIVE="psd_lin_horizontal_brill")
+        else:
+            mon = instrument.add_component("divergence_vertical_brill", "Div1D_monitor")
+            mon.ndiv = 200
+            mon.maxdiv = 2 * self["div_vertical"]
+            mon.vertical = 1
+            mon.set_ROTATED([0, 0, 0], RELATIVE="psd_lin_horizontal_brill")
+
         mon.filename = '"divergence_vertical_brill.dat"'
-        mon.h_maxdiv = 2 * self["div_vertical"]
         mon.xwidth = "target_height"
         mon.yheight = "target_width"
         mon.restore_neutron = 1
         mon.set_AT([0, 0, 1E-6], RELATIVE="PREVIOUS")
-        mon.set_ROTATED([0, 0, 90], RELATIVE="psd_lin_horizontal_brill")
         mon.set_WHEN("inside_h_div == 1")
 
         info = self.plot_info.new(mon, title="Linear divergence")
