@@ -18,7 +18,6 @@ from guide_bot.base_elements.guide_elements import GuideElement
 
 
 class Test_handle_input_parameter(unittest.TestCase):
-
     def test_simple_fixed_parameter(self):
         """
         Basic test of handle_input_parameter, fixed value given
@@ -146,7 +145,7 @@ class TestGuideElement(unittest.TestCase):
         element = Element("test")
 
         self.assertIsInstance(element.length, FreeInstrumentParameter)
-        self.assertEqual(element.length.get_lower_static_bound(), None)
+        self.assertEqual(element.length.get_lower_static_bound(), 0.1)
         self.assertEqual(element.length.get_upper_static_bound(), None)
 
         self.assertIsInstance(element.start_point, FreeInstrumentParameter)
@@ -234,7 +233,7 @@ class TestElement(unittest.TestCase):
         element = GuideElement("test")
 
         self.assertIsInstance(element.length, FreeInstrumentParameter)
-        self.assertEqual(element.length.get_lower_static_bound(), None)
+        self.assertEqual(element.length.get_lower_static_bound(), 0.1)
         self.assertEqual(element.length.get_upper_static_bound(), None)
 
         self.assertIsInstance(element.start_point, FreeInstrumentParameter)
@@ -271,7 +270,7 @@ class TestElement(unittest.TestCase):
         element = GuideElement("test")
 
         self.assertIsInstance(element.length, FreeInstrumentParameter)
-        self.assertEqual(element.length.get_lower_static_bound(), None)
+        self.assertEqual(element.length.get_lower_static_bound(), 0.1)
         self.assertEqual(element.length.get_upper_static_bound(), None)
 
         self.assertIsInstance(element.start_point, FreeInstrumentParameter)
@@ -301,4 +300,30 @@ class TestElement(unittest.TestCase):
 
         string = element.__repr__()  # check __repr__ doesn't fail
 
+    def test_connect_with_new_parameters(self):
+
+        element = GuideElement("test")
+
+        test_container = InstrumentParameterContainer()
+        dummy_instrument = 5.0
+
+        element.setup_instrument_and_parameters(dummy_instrument, test_container)
+        # element adds its start_width and start_height to test_container
+
+        test_container.set_values([0.5, 0.5])
+
+        self.assertEqual(element.start_width.get_value(), 0.5 * (0.005 + 0.15))
+        self.assertEqual(element.start_height.get_value(), 0.5 * (0.005 + 0.15))
+
+        print()
+        print(test_container)
+
+        new_container = InstrumentParameterContainer()
+        new_container.add_new_parameter("test_start_width", 37)
+        element.connect_to_new_parameters(new_container)
+        print(new_container)
+
+        self.assertEqual(element.start_width.get_value(), 37)
+        self.assertEqual(element.start_height.get_value(), 0.5 * (0.005 + 0.15))
+
 
